import java.awt.BorderLayout;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JToolBar;
import javax.swing.UIDefaults;
import javax.swing.UIManager;
import javax.swing.border.Border;
import javax.swing.border.BevelBorder;
import javax.swing.border.CompoundBorder;
import javax.swing.border.EmptyBorder;

public class ToolBarTest2 {

    private UIDefaults defaults = UIManager.getLookAndFeelDefaults();
    private Border rolloverBorder;
    private Border raisedBorder;
    private Border loweredBorder;

    public ToolBarTest2() {
        JFrame frame = new JFrame("ToolBarTest");
        frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        frame.setBounds(100, 100, 400, 200);

        rolloverBorder = createRolloverBorder();
        raisedBorder = createRaisedBevelBorder();
        loweredBorder = createLoweredBevelBorder();

        JToolBar toolbar = new JToolBar();

        JButton button = new JButton("Button1");
        toolbar.add(button);
        button.setBorder(rolloverBorder);
        button.addMouseListener(new RolloverAdapter());

        button = new JButton("Button2");
        toolbar.add(button);
        button.setBorder(rolloverBorder);
        button.addMouseListener(new RolloverAdapter());

        button = new JButton("Button3");
        toolbar.add(button);
        button.setBorder(rolloverBorder);
        button.addMouseListener(new RolloverAdapter());

        button = new JButton("Button4");
        toolbar.add(button);
        button.setBorder(rolloverBorder);
        button.addMouseListener(new RolloverAdapter());

        frame.getContentPane().add(toolbar, BorderLayout.NORTH);

        frame.setVisible(true);
    }

    private Border createRolloverBorder() {
        return new CompoundBorder(new EmptyBorder(2, 2, 3, 2), new EmptyBorder(3, 3, 3, 3));
    }

    private Border createRaisedBevelBorder() {
        return new CompoundBorder(new BevelBorder(BevelBorder.RAISED,
                                                  defaults.getColor("Button.light"),
                                                  defaults.getColor("Button.highlight"),
                                                  defaults.getColor("Button.shadow"),
                                                  defaults.getColor("Button.darkShadow")),
                                  new EmptyBorder(3, 3, 3, 3));
    }

    private Border createLoweredBevelBorder() {
        return new CompoundBorder(new BevelBorder(BevelBorder.LOWERED,
                                                  defaults.getColor("Button.light"),
                                                  defaults.getColor("Button.highlight"),
                                                  defaults.getColor("Button.shadow"),
                                                  defaults.getColor("Button.darkShadow")),
                                  new EmptyBorder(3, 3, 3, 3));
    }

    public class RolloverAdapter extends MouseAdapter {

        public void mousePressed(MouseEvent event){
            JButton button = (JButton)event.getSource();
            button.setBorder(loweredBorder);
        }

        public void mouseEntered(MouseEvent event){
            JButton button = (JButton)event.getSource();
            button.setBorder(raisedBorder);
        }

        public void mouseExited(MouseEvent event){
            JButton button = (JButton)event.getSource();
            button.setBorder(rolloverBorder);
        }
    }

    public static void main(String[] args) {
        new ToolBarTest2();
    }
}
